:orphan:

`plasmapy.dispersion.numerical`
===============================

.. currentmodule:: plasmapy.dispersion.numerical

.. automodapi:: plasmapy.dispersion.numerical

Example Notebooks
-----------------

.. nbgallery::

    /notebooks/dispersion/hollweg_dispersion
